@@ -143,10 +143,6 @@ namespace Breeze
         hide();
     }
 
-    //____________________________________________________________________
-    SplitterProxy::~SplitterProxy()
-    {}
-
     //____________________________________________________________________
     void SplitterProxy::setEnabled( bool value )
     {
